Sophie

Sophie

distrib > Mageia > 6 > armv7hl > media > core-updates-src > by-pkgid > 9ba55eebcc621d0cb935b577e189b8cd > files > 13

virtualbox-5.2.22-1.1.mga6.src.rpm


 src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp |   14 ++++++----
 1 file changed, 9 insertions(+), 5 deletions(-)

diff -Nurp VirtualBox-5.2.22/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp VirtualBox-5.2.22.mga/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp
--- VirtualBox-5.2.22/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp	2018-11-08 21:41:43.000000000 +0200
+++ VirtualBox-5.2.22.mga/src/VBox/Frontends/VirtualBox/src/widgets/UINameAndSystemEditor.cpp	2018-11-25 10:53:22.681644401 +0200
@@ -213,6 +213,10 @@ void UINameAndSystemEditor::prepareFamil
 
     /* Choose the 1st item to be the current: */
     m_pComboFamily->setCurrentIndex(0);
+    /* Default to Linux */
+    const int liIndex = m_pComboFamily->findData("Linux", TypeID);
+    if (liIndex != -1)
+        m_pComboFamily->setCurrentIndex(liIndex);
     /* And update the linked widgets accordingly: */
     sltFamilyChanged(m_pComboFamily->currentIndex());
 }
@@ -327,15 +331,15 @@ void UINameAndSystemEditor::sltFamilyCha
         if (iIndexWin7 != -1)
             m_pComboType->setCurrentIndex(iIndexWin7);
     }
     /* Or select Ubuntu item for Linux family as default: */
     else if (strFamilyId == "Linux")
     {
-        QString strDefaultID = "Ubuntu";
+        QString strDefaultID = "Mageia";
         if (ARCH_BITS == 64 && m_fSupportsHWVirtEx && m_fSupportsLongMode)
             strDefaultID += "_64";
-        const int iIndexUbuntu = m_pComboType->findData(strDefaultID, TypeID);
-        if (iIndexUbuntu != -1)
-            m_pComboType->setCurrentIndex(iIndexUbuntu);
+        const int iIndexMageia = m_pComboType->findData(strDefaultID, TypeID);
+        if (iIndexMageia != -1)
+            m_pComboType->setCurrentIndex(iIndexMageia);
     }
     /* Else simply select the first one present: */
     else
@@ -327,15 +331,15 @@ void UINameAndSystemEditor::sltFamilyCha
             m_pComboType->setCurrentIndex(iIndexWin7);
     }
-    /* Or select Ubuntu item for Linux family as default: */
+    /* Or select Mageia item for Linux family as default: */
     else if (strFamilyId == "Linux")
     {